Re: arp: some ether addr is using my IP address 0.0.0.0! ??!?!?

2001-10-20 Thread Max Khon

hi, there!

 Same here. My -CURRENT system is replying to those ARP request which carry
 0.0.0.0 as sender IP address:
 
 14:43:33.706099 arp who-has 158.227.48.193 (ff:ff:ff:ff:ff:ff) tell 0.0.0.0
 14:43:33.706152 arp reply 0.0.0.0 is-at 0:d0:b7:3e:a0:fb
 
  I think this is because I have an interface that is up and has NO IP
  address:
 
 I don't think so:
 
 # ifconfig -a
 fxp0: flags=8843UP,BROADCAST,RUNNING,SIMPLEX,MULTICAST mtu 1500
 inet 158.227.6.52 netmask 0xff00 broadcast 158.227.6.255
 inet6 fe80::2d0:b7ff:fe3e:a0fb%fxp0 prefixlen 64 scopeid 0x1 
 inet6 fec0::9ee3:634 prefixlen 120 
 ether 00:d0:b7:3e:a0:fb 
 media: Ethernet autoselect (100baseTX full-duplex)
 status: active
 lo0: flags=8049UP,LOOPBACK,RUNNING,MULTICAST mtu 16384
 inet6 ::1 prefixlen 128 
 inet6 fe80::1%lo0 prefixlen 64 scopeid 0x2 
 inet 127.0.0.1 netmask 0xff00 
 
 Something is broken in the ARP implementation of -CURRENT.

please try this patch (provided by jlemon)

Index: if_ether.c
===
RCS file: /ncvs/src/sys/netinet/if_ether.c,v
retrieving revision 1.85
diff -u -r1.85 if_ether.c
--- if_ether.c  2001/10/17 18:07:05 1.85
+++ if_ether.c  2001/10/19 15:38:07
@@ -593,10 +593,12 @@
isaddr.s_addr == ia-ia_addr.sin_addr.s_addr)
goto match;
/*
 * No match, use the first address on the receive interface
 * as a dummy address for the rest of the function.
 */
-   ifa = TAILQ_FIRST(ifp-if_addrhead);
+   TAILQ_FOREACH(ifa, ifp-if_addrhead, ifa_link)
+   if (ifa-ifa_addr  ifa-ifa_addr-sa_family == AF_INET)
+   break;
@@ -593,10 +593,12 @@
goto match;
/*
-* No match, use the first address on the receive interface
+* No match, use the first inet address on the receive interface
 * as a dummy address for the rest of the function.
 */
if (ifa == NULL) {
m_freem(m);
return;

/fjoe

To Unsubscribe: send mail to [EMAIL PROTECTED]
with unsubscribe freebsd-current in the body of the message



Re: lock order reversal on Alpha

2001-10-20 Thread Wilko Bulte

On Fri, Oct 19, 2001 at 01:02:50PM -0700, John Baldwin wrote:
 
 On 19-Oct-01 Wilko Bulte wrote:
  Fresh -current kernel on an DS10 Alpha box:
 
 I have untested patches to fix this.  Unfortunately they involve fixing the
 locking in teh clock code and I've only done i386 and alpha so far, but the
 same changes need to be replicated into all the otehr arch's.  Alternatively,
 we should have MI devices for the RTC and i8254 timers so that this code
 wouldn't be duplicated all over the place.  *sigh*
 
 If this is a UP box you should be able to just continue from this for now.

DS10 is UP yes. Tonight it ran a successful buildworld so it is not
always panicing ;)

-- 
|   / o / /_  _ email:  [EMAIL PROTECTED]
|/|/ / / /(  (_)  Bulte Arnhem, The Netherlands 

To Unsubscribe: send mail to [EMAIL PROTECTED]
with unsubscribe freebsd-current in the body of the message



Brand New AAA Credit -xbuhv

2001-10-20 Thread fred4865
Title: Instantly Get a Brand New AAA Credit Profile in 24 Hours!





Here's How You Can Have
a Brand New
Credit Profile in 24 Hours!
The
Best Part is... It's 100% Legal, 100% Ethical, and Fully GUARANTEED!

Dear Friend,
Do you have bad credit,
judgements, bankruptcies or
any other credit problems?
Does it seem like your bad
credit is holding
you back from qualifying for a major
credit card, car loan,
or even a department store card?
Are you sick of the
embarrassment of being rejected at
your attempts to get
any credit at all? If so... I've got
some extremely good
news for you.


I Will
Show You Precisely How to Get a New, Separate, Clean
Credit
File... and it will be Clear of Any Past Credit History!
And it's
100% LEGAL!





It doesn't
matter, if you have judgements!



It doesn't
matter, if you've filed for bankruptcy!



It doesn't
matter, if you've been foreclosed!



It doesn't
matter, if you have a tax lien!



It doesn't
matter, if have been a slow payer in the past!



It
Doesn't Matter, Because Your Credit File Will Be Completely
New
And Completely Independent Of Any Negative Past File!
With my kit...within
the next 60 days, you will quickly and easily





Get ALL Major Credit Cards



Learn Basic and Advanced
Credit Billing Techniques



Get Bank Loans FAST and
Simple



Get Mortgages NOW



Have AAA Credit on "Your
Brand New File" in 30-60 Days



Get INSTANT Credit From
Real Department Stores



Car Loans FAST and SIMPLE


And much, much more!


CLICK HERE TO LEARN MORE!


This email was sent to you by Coconut Bay Marketing Services in full compliance with all existing and proposed email legislation.
You may automatically remove yourself from any future mailings by clicking here. The reply address on this email was activeat the time this email was sent.  Coconut Bay Marketing Services, SJO3016  PO Box 025216, Miami, FL 33102








Current makeworld seems broken.

2001-10-20 Thread Edwin Culp

In case no one has seen this, I'm getting

(cd /usr/src/etc;  install -c -o root -g wheel -m 444 amd.map apmd.conf auth.con
f  crontab csh.cshrc csh.login csh.logout  dhclient.conf dm.conf fbtab ftpusers 
gettytab group  hosts hosts.allow hosts.equiv hosts.lpd  inetd.conf login.access
 login.conf  motd modems netconfig networks newsyslog.conf  pam.conf phones prin
tcap profile protocols  rc rc.atm rc.devfs rc.diskless1 rc.diskless2 rc.firewall
 rc.firewall6  rc.network rc.network6 rc.pccard rc.serial rc.shutdown  rc.syscon
s rc.sysctl remote rpc security services shells sysctl.conf  syslog.conf usbd.co
nf  etc.i386/disktab  etc.i386/rc.i386  etc.i386/ttys  /usr/src/etc/../gnu/usr.b
in/man/manpath/manpath.config  /usr/src/etc/../usr.bin/mail/misc/mail.rc  /usr/s
rc/etc/../usr.bin/locate/locate/locate.rc rc.isdn netstart pccard_ether rc.suspe
nd rc.resume  opieaccess /usr/share/examples/etc;  install -c -o root -g wheel -
m 444 defaults/rc.conf  /usr/share/examples/etc/defaults;  install -c -o root -g
 wheel -m 444 defaults/pccard.conf  /usr/share/examples/etc/defaults;  install -
c -o root -g wheel -m 444 defaults/periodic.conf  /usr/share/examples/etc/defaul
ts)
make: don't know how to make copies. Stop
*** Error code 2

ed


---

To Unsubscribe: send mail to [EMAIL PROTECTED]
with unsubscribe freebsd-current in the body of the message



Re: XFree86-4 required?

2001-10-20 Thread Peter Pentchev

On Fri, Oct 19, 2001 at 11:44:42AM -0700, David O'Brien wrote:
 On Thu, Oct 18, 2001 at 09:33:09PM +0200, Riccardo Torrini wrote:
  Is a real need for ports under -CURRENT to require (from a
  week or two, I don't remember) XFree86-libraries?
 
 Yes.

To elaborate a bit, the default XFree86 version in -current was
recently changed from 3 to 4.  Thus, if you still want to go with
your XFree86-3.x installation, you have to explicitly set
XFREE86_VERSION to 3.

G'luck,
Peter

-- 
This sentence no verb.

To Unsubscribe: send mail to [EMAIL PROTECTED]
with unsubscribe freebsd-current in the body of the message



Re: Current makeworld seems broken.

2001-10-20 Thread Glenn Gombert

Yes..I seem to be getting the same error message as well when I try to
make/install world.
-- 
Glenn Gombert
[EMAIL PROTECTED] - email
(513) 587-2643 x2263 - voicemail/fax



 Edwin Culp [EMAIL PROTECTED] wrote:
 In case no one has seen this, I'm getting
 
 (cd /usr/src/etc;  install -c -o root -g wheel -m 444 amd.map apmd.conf
 auth.con
 f  crontab csh.cshrc csh.login csh.logout  dhclient.conf dm.conf fbtab
 ftpusers 
 gettytab group  hosts hosts.allow hosts.equiv hosts.lpd  inetd.conf
 login.access
  login.conf  motd modems netconfig networks newsyslog.conf  pam.conf
 phones prin
 tcap profile protocols  rc rc.atm rc.devfs rc.diskless1 rc.diskless2
 rc.firewall
  rc.firewall6  rc.network rc.network6 rc.pccard rc.serial rc.shutdown
  rc.syscon
 s rc.sysctl remote rpc security services shells sysctl.conf  syslog.conf
 usbd.co
 nf  etc.i386/disktab  etc.i386/rc.i386  etc.i386/ttys  /usr/src/etc/../gnu/usr.b
 in/man/manpath/manpath.config  /usr/src/etc/../usr.bin/mail/misc/mail.rc
  /usr/s
 rc/etc/../usr.bin/locate/locate/locate.rc rc.isdn netstart pccard_ether
 rc.suspe
 nd rc.resume  opieaccess /usr/share/examples/etc;  install -c -o root
 -g wheel -
 m 444 defaults/rc.conf  /usr/share/examples/etc/defaults;  install
 -c -o root -g
  wheel -m 444 defaults/pccard.conf  /usr/share/examples/etc/defaults;
  install -
 c -o root -g wheel -m 444 defaults/periodic.conf  /usr/share/examples/etc/defaul
 ts)
 make: don't know how to make copies. Stop
 *** Error code 2
 
 ed
 
 
 ---
 
 To Unsubscribe: send mail to [EMAIL PROTECTED]
 with unsubscribe freebsd-current in the body of the message
 

__
FREE voicemail, email, and fax...all in one place.
Sign Up Now! http://www.onebox.com


To Unsubscribe: send mail to [EMAIL PROTECTED]
with unsubscribe freebsd-current in the body of the message



Re: NT filesystem panicking my current box

2001-10-20 Thread Matthew Dillon

Try turning off vmiodirenable:

   sysctl -w vfs.vmiodirenable=0

And see if that makes a difference.

-Matt

:On one of my current boxes I run amanda, which some 2 weeks ago (after an
:upgrade to that current) started dying reliable when the backup started.
:
:the ntfs FS is mounted on /nt
:
:2 seconds of testing showed that 'tar -czf /dev/null /nt' was enough for
:a kernel panick within 2 seconds.
:
:A few upgrades later the problem still exists.
:
:Before I go through the trouble of collecting the backtraces and make
:kernel dumps and all: do other people have this problem as well? Or is
:this part of the NTFS module not really updated after the KSE happening?
:(I have now disabled all local filesystems from the backup, since only
:excluding the NTFS backup didn't solve the problem, still a crash, that
:one I haven't looked at later on)
:
:Mark

To Unsubscribe: send mail to [EMAIL PROTECTED]
with unsubscribe freebsd-current in the body of the message